@@ -5,6 +5,26 @@
 #include <argparse/argparse_decl.hpp>
 #include "./catch-define.h"
 
+#ifndef _ARGPARSE_CXX_11
+void
+parser_a_handle_check(argparse::Namespace const& args)
+{
+    REQUIRE(args.exists("foo") == false);
+    REQUIRE(args.exists("cmd") == true);
+    REQUIRE(args.exists("bar") == true);
+    REQUIRE(args.exists("baz") == false);
+}
+
+void
+parser_b_handle_check(argparse::Namespace const& args)
+{
+    REQUIRE(args.exists("foo") == false);
+    REQUIRE(args.exists("cmd") == true);
+    REQUIRE(args.exists("bar") == false);
+    REQUIRE(args.exists("baz") == true);
+}
+#endif  // C++11-
+
 TEST_CASE("1. subparsers", "[argument_parser]")
 {
     argparse::ArgumentParser parser = argparse::ArgumentParser().exit_on_error(false);
@@ -12,7 +32,7 @@ TEST_CASE("1. subparsers", "[argument_parser]")
     SECTION("1.1. main parser without positional arguments (required=false)") {
         parser.add_argument("--foo").action("store_true").help("foo help");
 
-        argparse::ArgumentParser::Subparser& subparsers = parser.add_subparsers().dest("cmd").help("sub-command help");
+        argparse::SubParsers& subparsers = parser.add_subparsers().dest("cmd").help("sub-command help");
 
         argparse::ArgumentParser& parser_a = subparsers.add_parser("a").help("a help");
         parser_a.add_argument("bar").help("bar help");
@@ -51,7 +71,7 @@ TEST_CASE("1. subparsers", "[argument_parser]")
         parser.add_argument("--foo").action("store_true").help("foo help");
         parser.add_argument("boo").action("store").help("boo help");
 
-        argparse::ArgumentParser::Subparser& subparsers = parser.add_subparsers().dest("cmd").help("sub-command help");
+        argparse::SubParsers& subparsers = parser.add_subparsers().dest("cmd").help("sub-command help");
 
         argparse::ArgumentParser& parser_a = subparsers.add_parser("a").help("a help");
         parser_a.add_argument("bar").help("bar help");
@@ -121,7 +141,7 @@ TEST_CASE("1. subparsers", "[argument_parser]")
         parser.add_argument("boo").action("store_true").help("boo help");
         parser.add_argument("doo").action("store_false").help("doo help");
 
-        argparse::ArgumentParser::Subparser& subparsers = parser.add_subparsers().dest("cmd").help("sub-command help");
+        argparse::SubParsers& subparsers = parser.add_subparsers().dest("cmd").help("sub-command help");
 
         argparse::ArgumentParser& parser_a = subparsers.add_parser("a").help("a help");
         parser_a.add_argument("bar").help("bar help");
@@ -189,7 +209,7 @@ TEST_CASE("1. subparsers", "[argument_parser]")
         parser.add_argument("-1").dest("one").help("one help");
         parser.add_argument("--foo").action("store_true").help("foo help");
 
-        argparse::ArgumentParser::Subparser& subparsers = parser.add_subparsers().dest("cmd").help("sub-command help");
+        argparse::SubParsers& subparsers = parser.add_subparsers().dest("cmd").help("sub-command help");
 
         argparse::ArgumentParser& parser_a = subparsers.add_parser("a").help("a help");
         parser_a.add_argument("bar").help("bar help");
@@ -230,11 +250,11 @@ TEST_CASE("1. subparsers", "[argument_parser]")
         REQUIRE_THROWS(parser.parse_args(_make_vec("-1", "-1")));
     }
 
-    SECTION("1.5. subparser with negative number options present") {
+    SECTION("1.5. subparsers with negative number options present") {
         parser.add_argument("--foo").action("store_true").help("foo help");
         parser.add_argument("--boo").action("store").help("boo help");
 
-        argparse::ArgumentParser::Subparser& subparsers = parser.add_subparsers().dest("cmd").help("sub-command help");
+        argparse::SubParsers& subparsers = parser.add_subparsers().dest("cmd").help("sub-command help");
 
         argparse::ArgumentParser& parser_a = subparsers.add_parser("a").help("a help");
         parser_a.add_argument("bar").help("bar help");
@@ -243,7 +263,7 @@ TEST_CASE("1. subparsers", "[argument_parser]")
         argparse::ArgumentParser& parser_b = subparsers.add_parser("b").help("b help");
         parser_b.add_argument("--baz").choices("XYZ").help("baz help");
 
-        // so -1 is an option in subparser
+        // so -1 is an option in subparsers
         argparse::Namespace args0 = parser.parse_args(_make_vec("--boo", "-1", "a", "-1", "x", "1"));
         REQUIRE(args0.exists("bar") == true);
         REQUIRE(args0.exists("baz") == false);
@@ -262,16 +282,16 @@ TEST_CASE("1. subparsers", "[argument_parser]")
         REQUIRE(args1.get<bool>("foo") == false);
         REQUIRE(args1.get<std::string>("cmd") == "a");
 
-        // so -2 is an option in subparser
+        // so -2 is an option in subparsers
         REQUIRE_THROWS(parser.parse_args(_make_vec("a", "-1", "x", "-2")));
-        // so both -1s are options in subparser
+        // so both -1s are options in subparsers
         REQUIRE_THROWS(parser.parse_args(_make_vec("a", "-1", "-1")));
     }
 
-    SECTION("1.6. subparser required=true") {
+    SECTION("1.6. subparsers required=true") {
         parser.add_argument("--foo").action("store_true").help("foo help");
 
-        argparse::ArgumentParser::Subparser& subparsers
+        argparse::SubParsers& subparsers
                 = parser.add_subparsers().required(true).dest("cmd").help("sub-command help");
 
         argparse::ArgumentParser& parser_a = subparsers.add_parser("a").help("a help");
@@ -284,10 +304,10 @@ TEST_CASE("1. subparsers", "[argument_parser]")
         REQUIRE_THROWS(parser.parse_args(_make_vec("--foo")));
     }
 
-    SECTION("1.7. subparser namespace handle") {
+    SECTION("1.7. subparsers namespace handle") {
         parser.add_argument("--foo").action("store_true").help("foo help");
 
-        argparse::ArgumentParser::Subparser& subparsers = parser.add_subparsers().dest("cmd").help("sub-command help");
+        argparse::SubParsers& subparsers = parser.add_subparsers().dest("cmd").help("sub-command help");
 
         argparse::ArgumentParser& parser_a = subparsers.add_parser("a").help("a help");
 #ifdef _ARGPARSE_CXX_11
@@ -298,6 +318,8 @@ TEST_CASE("1. subparsers", "[argument_parser]")
             REQUIRE(args.exists("bar") == true);
             REQUIRE(args.exists("baz") == false);
         });
+#else
+        parser_a.handle(&parser_a_handle_check);
 #endif  // C++11+
         parser_a.add_argument("bar").help("bar help");
         REQUIRE(subparsers.parser_names().size() == 1);
@@ -311,6 +333,8 @@ TEST_CASE("1. subparsers", "[argument_parser]")
              REQUIRE(args.exists("bar") == false);
              REQUIRE(args.exists("baz") == true);
         });
+#else
+        parser_b.handle(&parser_b_handle_check);
 #endif  // C++11+
         parser_b.add_argument("--baz").choices("XYZ").help("baz help");
         REQUIRE(subparsers.parser_names().size() == 2);
